/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V3.4.0
  * @date    29-June-2012
  * @brief   Joystick Mouse demo main file
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2012 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "hw_config.h"
#include "usb_lib.h"
#include "usb_pwr.h"

#include "Custom.h"
#include "..\Test\LEDs_Button\LEDs_Button.h"
#include "..\Test\RTC\RTC.h"
#include "..\Test\USB_Mouse\USB_Mouse.h"

#include <stdio.h>
#include <string.h>

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

/* Extern variables ----------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

void USART_Initialize (COM_TypeDef COMx)
{
  USART_InitTypeDef USART_InitStructure;
  USART_InitStructure.USART_BaudRate = 115200;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
  STM_EVAL_COMInit(COMx, &USART_InitStructure);
}

void Demo_Routine ()
{
  extern __IO uint32_t TimeDisplay;     // RTC update flag
  extern __IO uint8_t PrevXferComplete; // USB mouse flag
  char Buff[16];
  unsigned int Time;
  RTC_Init ();
  USART_Write_String ("\fLED will blink with 1Hz frequnecy (RTC)\n\r");
  USART_Write_String ("On the terminal elapsed time will be printed\n\r");
  USART_Write_String ("Push the button to spin the mouse cursor\n\r");
  while (1)
  {
    // RTC & LED
    if (TimeDisplay)
    {
      LED_Toggle ();
      Time = RTC_GetCounter();
      sprintf (Buff, "%.2d:%.2d:%.2d\r", Time/3600, Time/60%60, Time%60);
      USART_Write_String (Buff);
      TimeDisplay = 0;
    }

    // USB & Button
    if (Button_Pressed() && (bDeviceState == CONFIGURED))
      for (int i=0; i<4; i++)
      {
        while (!PrevXferComplete);
        Mouse_Coursor (i, CURSOR_STEP);
      }
  }
}


/*******************************************************************************
* Function Name  : main.
* Description    : main routine.
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/

int main(void)
{
  Set_System();
  USB_Interrupts_Config();
  Set_USBClock();
  USB_Init();
  USART_Initialize (CHOSEN_COM);
  LEDs_Button_Init ();

  Demo_Routine ();
}

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
